@@ -136,13 +136,15 @@ impl<'a, I: Tokens> Parser<I> {
 
     pub(super) fn eat_any_ts_modifier(&mut self) -> PResult<bool> {
         let has_modifier = self.syntax().typescript()
-            && match *cur!(self, false)? {
-                Word(Word::Ident(js_word!("public")))
-                | Word(Word::Ident(js_word!("protected")))
-                | Word(Word::Ident(js_word!("private")))
-                | Word(Word::Ident(js_word!("readonly"))) => true,
-                _ => false,
-            }
+            && matches!(
+                *cur!(self, false)?,
+                Word(Word::Ident(
+                    js_word!("public")
+                        | js_word!("protected")
+                        | js_word!("private")
+                        | js_word!("readonly")
+                ))
+            )
             && (peeked_is!(self, IdentName) || peeked_is!(self, '{') || peeked_is!(self, '['));
         if has_modifier {
             let _ = self.parse_ts_modifier(&["public", "protected", "private", "readonly"], false);
